import * as vscode from 'vscode';
export const ntADecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: 'rgb(71,255,25)',
    color: 'rgb(0, 0, 0)'
});
export const ntTDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: 'rgb(65, 146, 255)',
    color: 'rgb(0, 0, 0)'
});
export const ntGDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: 'rgb(240, 144, 0)',
    color: 'rgb(0, 0, 0)'
});
export const ntCDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#FF4641',
    color: 'rgb(0, 0, 0)'
});
export const ntUDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#8A89FF',
    color: 'rgb(0, 0, 0)'
});
export const ntRDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#FFFE80',
    color: 'rgb(0, 0, 0)'
});
export const ntYDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#E180FF',
    color: 'rgb(0, 0, 0)'
});
export const ntSDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#FF9B80',
    color: 'rgb(0, 0, 0)'
});
export const ntWDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#80FFF2',
    color: 'rgb(0, 0, 0)'
});
export const ntMDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#CE8834',
    color: 'rgb(0, 0, 0)'
});
export const ntKDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#90B82C',
    color: 'rgb(0, 0, 0)'
});
export const ntDDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#C7FFB9',
    color: 'rgb(0, 0, 0)'
});
export const ntBDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#F8C1C0',
    color: 'rgb(0, 0, 0)'
});
export const ntVDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#FFE3B9',
    color: 'rgb(0, 0, 0)'
});
export const ntHDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#BFD8F9',
    color: 'rgb(0, 0, 0)'
});

export const ntNDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#FFFFFF',
    color: 'rgb(0, 0, 0)'
});
export const ntXDecorationType = vscode.window.createTextEditorDecorationType({
    color: '#E6E6E6'
});
export const ntGapDecorationType = vscode.window.createTextEditorDecorationType({
    color: '#E6E6E6'
});
