"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
exports.ntADecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: 'rgb(71,255,25)',
    color: 'rgb(0, 0, 0)'
});
exports.ntTDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: 'rgb(65, 146, 255)',
    color: 'rgb(0, 0, 0)'
});
exports.ntGDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: 'rgb(240, 144, 0)',
    color: 'rgb(0, 0, 0)'
});
exports.ntCDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#FF4641',
    color: 'rgb(0, 0, 0)'
});
exports.ntUDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#8A89FF',
    color: 'rgb(0, 0, 0)'
});
exports.ntRDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#FFFE80',
    color: 'rgb(0, 0, 0)'
});
exports.ntYDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#E180FF',
    color: 'rgb(0, 0, 0)'
});
exports.ntSDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#FF9B80',
    color: 'rgb(0, 0, 0)'
});
exports.ntWDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#80FFF2',
    color: 'rgb(0, 0, 0)'
});
exports.ntMDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#CE8834',
    color: 'rgb(0, 0, 0)'
});
exports.ntKDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#90B82C',
    color: 'rgb(0, 0, 0)'
});
exports.ntDDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#C7FFB9',
    color: 'rgb(0, 0, 0)'
});
exports.ntBDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#F8C1C0',
    color: 'rgb(0, 0, 0)'
});
exports.ntVDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#FFE3B9',
    color: 'rgb(0, 0, 0)'
});
exports.ntHDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#BFD8F9',
    color: 'rgb(0, 0, 0)'
});
exports.ntNDecorationType = vscode.window.createTextEditorDecorationType({
    backgroundColor: '#FFFFFF',
    color: 'rgb(0, 0, 0)'
});
exports.ntXDecorationType = vscode.window.createTextEditorDecorationType({
    color: '#E6E6E6'
});
exports.ntGapDecorationType = vscode.window.createTextEditorDecorationType({
    color: '#E6E6E6'
});
//# sourceMappingURL=decorations.js.map